@@ -11,8 +11,8 @@ class EnvLoader:
         values [OrderedDict]: The loaded environmental values, might be empty.
     """
 
-    def __init__(self) -> None:
-        self.values = dotenv_values()
+    def __init__(self, env_path : str = ".env") -> None:
+        self.values = dotenv_values(env_path)
 
     def get_ip(self) -> Optional[str]:
         """Obtains MISTY_IP_ADDRESS from environmental values."""
